pub enum Placement {
LeftTop(Handle<UiNode>),
RightTop(Handle<UiNode>),
Center(Handle<UiNode>),
LeftBottom(Handle<UiNode>),
RightBottom(Handle<UiNode>),
Cursor(Handle<UiNode>),
Position {
position: Vector2<f32>,
target: Handle<UiNode>,
},
}Variants
LeftTop(Handle<UiNode>)
A popup should be placed relative to given widget at the left top corner of the widget screen bounds.
Widget handle could be NONE, in this case the popup will be placed at the left top corner of the screen.
RightTop(Handle<UiNode>)
A popup should be placed relative to given widget at the right top corner of the widget screen bounds.
Widget handle could be NONE, in this case the popup will be placed at the right top corner of the screen.
Center(Handle<UiNode>)
A popup should be placed relative to given widget at the center of the widget screen bounds.
Widget handle could be NONE, in this case the popup will be placed at the center of the screen.
LeftBottom(Handle<UiNode>)
A popup should be placed relative to given widget at the left bottom corner of the widget screen bounds.
Widget handle could be NONE, in this case the popup will be placed at the left bottom corner of the screen.
RightBottom(Handle<UiNode>)
A popup should be placed relative to given widget at the right bottom corner of the widget screen bounds.
Widget handle could be NONE, in this case the popup will be placed at the right bottom corner of the screen.
Cursor(Handle<UiNode>)
A popup should be placed at the cursor position. The widget handle could be either NONE or a handle of a
widget that is directly behind the cursor.
Position
A popup should be placed at given screen-space position.