#[repr(u32)]pub enum TextCommitMode {
Immediate = 0,
LostFocus = 1,
LostFocusPlusEnter = 2,
}Variants
Immediate = 0
Text box will immediately send Text message after any change.
LostFocus = 1
Text box will send Text message only when it loses focus.
LostFocusPlusEnter = 2
Text box will send Text message when it loses focus or if Enter key was pressed. This is default behavior.
Notes
In case of multiline text box hitting Enter key won’t commit text!